#[non_exhaustive]pub struct PosixAccount {
pub primary: bool,
pub username: String,
pub uid: i64,
pub gid: i64,
pub home_directory: String,
pub shell: String,
pub gecos: String,
pub system_id: String,
pub account_id: String,
pub operating_system_type: OperatingSystemType,
pub name: String,
/* private fields */
}Expand description
The POSIX account information associated with a Google account.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.primary: boolOnly one POSIX account can be marked as primary.
username: StringThe username of the POSIX account.
uid: i64The user ID.
gid: i64The default group ID.
home_directory: StringThe path to the home directory for this account.
shell: StringThe path to the logic shell for this account.
gecos: StringThe GECOS (user information) entry for this account.
system_id: StringSystem identifier for which account the username or uid applies to. By default, the empty value is used.
account_id: StringOutput only. A POSIX account identifier.
operating_system_type: OperatingSystemTypeThe operating system type where this account applies.
name: StringOutput only. The canonical resource name.
Implementations
Sourceimpl PosixAccount
impl PosixAccount
pub fn new() -> Self
Sourcepub fn set_primary<T: Into<bool>>(self, v: T) -> Self
pub fn set_primary<T: Into<bool>>(self, v: T) -> Self
Sourcepub fn set_username<T: Into<String>>(self, v: T) -> Self
pub fn set_username<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_home_directory<T: Into<String>>(self, v: T) -> Self
pub fn set_home_directory<T: Into<String>>(self, v: T) -> Self
Sets the value of home_directory.
Example
ⓘ
let x = PosixAccount::new().set_home_directory("example");Sourcepub fn set_system_id<T: Into<String>>(self, v: T) -> Self
pub fn set_system_id<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_account_id<T: Into<String>>(self, v: T) -> Self
pub fn set_account_id<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_operating_system_type<T: Into<OperatingSystemType>>(
self,
v: T,
) -> Self
pub fn set_operating_system_type<T: Into<OperatingSystemType>>( self, v: T, ) -> Self
Sets the value of operating_system_type.
Example
ⓘ
use google_cloud_oslogin_common::model::OperatingSystemType;
let x0 = PosixAccount::new().set_operating_system_type(OperatingSystemType::Linux);
let x1 = PosixAccount::new().set_operating_system_type(OperatingSystemType::Windows);Trait Implementations
Sourceimpl Clone for PosixAccount
impl Clone for PosixAccount
Sourcefn clone(&self) -> PosixAccount
fn clone(&self) -> PosixAccount
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PosixAccount
impl Debug for PosixAccount
Sourceimpl Default for PosixAccount
impl Default for PosixAccount
Sourcefn default() -> PosixAccount
fn default() -> PosixAccount
Returns the “default value” for a type. Read more
Sourceimpl Message for PosixAccount
impl Message for PosixAccount
Sourceimpl PartialEq for PosixAccount
impl PartialEq for PosixAccount
impl StructuralPartialEq for PosixAccount